# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector_v2.models.usage_details import UsageDetails

class TestUsageDetails(unittest.TestCase):
    """UsageDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsageDetails:
        """Test UsageDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsageDetails`
        """
        model = UsageDetails()
        if include_optional:
            return UsageDetails(
                input_tokens = 56,
                model = '',
                output_tokens = 56
            )
        else:
            return UsageDetails(
                input_tokens = 56,
                model = '',
                output_tokens = 56,
        )
        """

    def testUsageDetails(self):
        """Test UsageDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector_v2.models.goal_interactions_summary import GoalInteractionsSummary

class TestGoalInteractionsSummary(unittest.TestCase):
    """GoalInteractionsSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoalInteractionsSummary:
        """Test GoalInteractionsSummary
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoalInteractionsSummary`
        """
        model = GoalInteractionsSummary()
        if include_optional:
            return GoalInteractionsSummary(
                is_available = True,
                last_engagement_at = 56,
                last_opt_out_at = 56,
                recent_interaction_count = 56,
                total_interaction_count = 56
            )
        else:
            return GoalInteractionsSummary(
        )
        """

    def testGoalInteractionsSummary(self):
        """Test GoalInteractionsSummary"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector_v2.models.portal_ai_info_get import PortalAiInfoGet

class TestPortalAiInfoGet(unittest.TestCase):
    """PortalAiInfoGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PortalAiInfoGet:
        """Test PortalAiInfoGet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PortalAiInfoGet`
        """
        model = PortalAiInfoGet()
        if include_optional:
            return PortalAiInfoGet(
                academy_info = '',
                agent_name = '',
                agent_personality = '',
                created_at = 56,
                goal = '',
                last_updated_at = 56,
                portal_id = 56,
                portal_owner_info = ''
            )
        else:
            return PortalAiInfoGet(
                created_at = 56,
                last_updated_at = 56,
                portal_id = 56,
        )
        """

    def testPortalAiInfoGet(self):
        """Test PortalAiInfoGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
